@@ -10,6 +10,7 @@
 (***********************************************************************)
 
 type saved
+
 val checkpoint : unit -> saved
 val hot_start : saved -> unit
 
@@ -18,4 +19,5 @@ val def_counter: string -> string -> unit
 val set_counter: string -> int -> unit
 val add_counter:string -> int -> unit
 val step_counter: string -> unit
-val number_within: string -> string -> unit
+val addtoreset: string -> string -> unit
+val removefromreset: string -> string -> unit
